==> haskell-checkers-0.4.11-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.11
id: checkers-0.4.11-4QlBQTfYxaqEdJr6Q87e8k
key: checkers-0.4.11-4QlBQTfYxaqEdJr6Q87e8k
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: ff97cc398d3aa46525c55375d4741420
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.4.3/site-local/checkers-0.4.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/checkers-0.4.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/checkers-0.4.11
hs-libraries: HScheckers-0.4.11-4QlBQTfYxaqEdJr6Q87e8k
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr array-0.5.2.0
    base-4.11.1.0 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    semigroupoids-5.3.1-5yqExbNHNs5HvmpD7pxLfb
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             semigroupoids-5.3.1-5yqExbNHNs5HvmpD7pxLfb=1e26706ac3e6c4ab8467a720a672b919
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.4.11-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.11
id: checkers-0.4.11-5O7I5j4lQmtG82smyRRV7u
key: checkers-0.4.11-5O7I5j4lQmtG82smyRRV7u
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: b15b3d40f2c53df8ae1c9ebe5a4861f0
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.1/site-local/checkers-0.4.11
library-dirs: /usr/lib/ghc-8.6.1/site-local/checkers-0.4.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/checkers-0.4.11
hs-libraries: HScheckers-0.4.11-5O7I5j4lQmtG82smyRRV7u
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc array-0.5.2.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.1-BNB1J3DLDzM732CwrpQKex
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
